@@ -106,7 +106,9 @@ def app_factory(args: argparse.Namespace):
         max_packets=(
             args.packets
             if args.packets is not None
-            else args.fps * args.duration if args.duration else None
+            else args.fps * args.duration
+            if args.duration
+            else None
         ),
     )
 
@@ -369,7 +371,7 @@ def main(args=None):
         print("\nCancelling...")
         sys.exit(1)
 
-    except Exception as exc:  # pylint: disable=broad-exception-caught
+    except Exception as exc:
         print(f"Failed with error: {exc}")
         sys.exit(1)
 
